simplify.InvoiceItem

Package simplify :: Class InvoiceItem |
[hide private]
[frames] | no frames]

# Class InvoiceItem

source code

    domain.Domain --+
                    |
                   InvoiceItem

A InvoiceItem object.

Instance Methods | [hide private]
delete(self, *auth_args) Delete this object | source code
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an InvoiceItem object | source code
find(object_id, *auth_args) Retrieve a InvoiceItem object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an InvoiceItem object Parameters: `params` - a dict of parameters; valid keys are: `amount`: Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00 required `description`: Individual items of an invoice [max length: 1024] `invoice`: The ID of the invoice this item belongs to. `product`: Product ID this item relates to. `quantity`: Quantity of the item. This total amount of the invoice item is the amount * quantity. [min value: 1, max value: 999999, default: 1] `reference`: User defined reference field. [max length: 255] `tax`: The tax ID of the tax charge in the invoice item. `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a InvoiceItem object

### delete(self, *auth_args) | source code
Delete this object Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object.

### find(object_id, *auth_args) Static Method | source code
Retrieve a InvoiceItem object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a InvoiceItem object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: `amount` Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00 [min value: 1] `description` Individual items of an invoice `quantity` Quantity of the item. This total amount of the invoice item is the amount * quantity. [min value: 1, max value: 999999] `reference` User defined reference field. `tax` The tax ID of the tax charge in the invoice item. Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a InvoiceItem object.